@@ -10,7 +10,6 @@
 #include "xcb_framebuffer.h"
 #include "krfb_fb_xcb_debug.h"
 
-#include <xcb/xcb.h>
 #include <xcb/xproto.h>
 #include <xcb/damage.h>
 #include <xcb/shm.h>
@@ -605,7 +604,7 @@ QList<QRect> XCBFrameBuffer::modifiedTiles() {
         } else {
             // not using shared memory
             // will use just xcb_image_get() and copy pixels
-            for (const QRect& r : qAsConst(tiles)) {
+            for (const QRect& r : std::as_const(tiles)) {
                 // I did not find XGetSubImage() analog in XCB!!
                 // need function that copies pixels from one image to another
                 xcb_image_t *damagedImage = xcb_image_get(
